@@ -6,6 +6,7 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
 	dpb "github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
 )
 
@@ -36,6 +37,17 @@ type DetectorID struct {
 	Version int
 }
 
+func GetDetectorID(d detectors.Detector) DetectorID {
+	var version int
+	if v, ok := d.(detectors.Versioner); ok {
+		version = v.Version()
+	}
+	return DetectorID{
+		ID:      d.Type(),
+		Version: version,
+	}
+}
+
 // ParseDetectors parses user supplied string into a list of detectors types.
 // "all" will return the list of all available detectors. The input is comma
 // separated and may use the case-insensitive detector name defined in the
